(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     52827,       1362]
NotebookOptionsPosition[     14338,        501]
NotebookOutlinePosition[     50372,       1284]
CellTagsIndexPosition[     50329,       1281]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["", "SlideShowNavigationBar"],

Cell["World Population Lab Activity", "Title"],

Cell["", "Spacer"],

Cell[TextData[{
 StyleBox["Teacher:",
  FontWeight->"Bold"],
 " Andy Dorsett\n",
 StyleBox["Class:",
  FontWeight->"Bold"],
 " Calculus 1"
}], "ClassInfo"],

Cell["\<\


\
\>", "Spacer"],

Cell[TextData[{
 StyleBox["Activity",
  FontSlant->"Italic"],
 ": Explore population growth by looking at a country that has had a \
decreasing population in recent years, such as Romania."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["\<\
Get population data for Romania\
\>", "Section"],

Cell[TextData[{
 "We can use free-form input to find this information...or, we can explicitly \
use the ",
 ButtonBox["CountryData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/CountryData"],
 " function ourselves."
}], "Text"],

Cell["\<\
 Let\[CloseCurlyQuote]s do that, and store the result in a variable for some \
future calculations.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"data", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"year", ",", 
      RowBox[{"CountryData", "[", 
       RowBox[{"\"\<Romania\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Population\>\"", ",", "year"}], "}"}]}], "]"}]}], "}"}],
     ",", 
    RowBox[{"{", 
     RowBox[{"year", ",", "1970", ",", "2005", ",", "1"}], "}"}]}], 
   "]"}]}]], "Input"],

Cell["", "Spacer"],

Cell[CellGroupData[{

Cell["Plot the population trend", "Subsection"],

Cell[TextData[{
 "We use the ",
 ButtonBox["ListPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ListPlot"],
 " function to plot 2D data."
}], "Text"],

Cell[BoxData[
 RowBox[{"ListPlot", "[", "data", "]"}]], "Input"],

Cell["\<\
It looks like the population peaks in the late 1980s or early 1990s.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Fit the data", "Section"],

Cell["\<\
Let\[CloseCurlyQuote]s try to fit a simple function to this data \[Dash] \
perhaps a parabola.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"model", "=", 
  RowBox[{"LinearModelFit", "[", 
   RowBox[{"data", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "x", ",", 
      SuperscriptBox["x", "2"]}], "}"}], ",", "x"}], "]"}]}]], "Input"],

Cell["", "Space"],

Cell[CellGroupData[{

Cell["Compare the data and the fit", "Subsection"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s put the actual data points together with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s fit to see how good it is."
}], "Text"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", "data", "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"model", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "1970", ",", "2005"}], "}"}]}], "]"}]}], 
  "]"}]], "Input"],

Cell[TextData[{
 "Not bad! ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " found a pretty good fit with the parabola."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Further analysis", "Section"],

Cell["\<\
Now, let\[CloseCurlyQuote]s see if we can make some guesses as to what year \
the population peaked. If we evaluate the below code, we can use the \
resulting interactive model to enter different years and explore the slope of \
the line tangent to the parabola at those years.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"x1", "=", "2000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Column", "[", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Row", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<Enter a year and hit enter: \>\"", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Arial\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}], ",", 
       RowBox[{"InputField", "[", 
        RowBox[{"Dynamic", "[", "x1", "]"}], "]"}]}], "}"}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Dynamic", "@", "\[IndentingNewLine]", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"ListPlot", "[", 
        RowBox[{"data", ",", 
         RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"\"\<The slope at \>\"", "<>", 
             RowBox[{"ToString", "[", "x1", "]"}], "<>", "\"\< is: \>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{
               RowBox[{"model", "'"}], "[", "x1", "]"}], "]"}]}], ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Arial\>\""}]}], "]"}]}]}], 
        "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"model", "[", "x", "]"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"model", "'"}], "[", "x1", "]"}], "*", 
             RowBox[{"(", 
              RowBox[{"x", "-", "x1"}], ")"}]}], "+", 
            RowBox[{"model", "[", "x1", "]"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "400"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "1970", ",", "2005"}], "}"}]}], "]"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "}"}], "]"}]}], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[{
      StyleBox["\"Enter a year and hit enter: \"", StripOnInput -> False, 
        FontFamily -> "Arial", FontSize -> 16],InputFieldBox[
        Dynamic[$CellContext`x1]]},
      "Row",
      DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
      InterpretationFunction->(RowBox[{"Row", "[", 
         RowBox[{"{", 
           RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
    {
     DynamicBox[ToBoxes[
       Show[
        ListPlot[$CellContext`data, ImageSize -> 400, PlotLabel -> Style[
           StringJoin["The slope at ", 
            ToString[$CellContext`x1], " is: ", 
            ToString[
             Derivative[1][$CellContext`model][$CellContext`x1]]], FontFamily -> 
           "Arial"]], 
        Plot[{
          $CellContext`model[$CellContext`x], 
          Derivative[
            1][$CellContext`model][$CellContext`x1] ($CellContext`x - \
$CellContext`x1) + $CellContext`model[$CellContext`x1], ImageSize -> 
          400}, {$CellContext`x, 1970, 2005}]], StandardForm],
      ImageSizeCache->{400., {121., 125.}}]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output"]
}, {2}]],

Cell[TextData[{
 "Of course, we can calculate the slope of the tangent line directly by \
finding the value of the derivative of the parabola (which we named ",
 StyleBox["model", "MR"],
 ") at specific years."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "'"}], "[", "1989", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "'"}], "[", "1990", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model", "'"}], "[", "1991", "]"}]], "Input"],

Cell["\<\
We notice the slope of the tangent line changes from positive to negative, \
which indicates that we are near a critical value, the maximum.\
\>", "Text"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to find the specific maximum value for this parabola."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"FindMaximum", "[", 
  RowBox[{
   RowBox[{"model", "[", "x", "]"}], ",", "x"}], "]"}]], "Input"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " found that 1990 was when the population peaked. Evaluate the below code \
and use the resulting model to explore this in more detail."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{"data", ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"2.0", "*", 
           SuperscriptBox["10", "7"]}], ",", 
          RowBox[{"2.5", "*", 
           SuperscriptBox["10", "7"]}]}], "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", "Large", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{"x1", ",", 
             RowBox[{"model", "[", "x1", "]"}]}], "}"}], "]"}]}], "}"}]}], 
       ",", 
       RowBox[{"AxesOrigin", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1970", ",", 
          RowBox[{"2.0", "*", 
           SuperscriptBox["10", "7"]}]}], "}"}]}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"model", "[", "x", "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"model", "'"}], "[", "x1", "]"}], "*", 
           RowBox[{"(", 
            RowBox[{"x", "-", "x1"}], ")"}]}], "+", 
          RowBox[{"model", "[", "x1", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1970", ",", "2005"}], "}"}]}], "]"}]}], "]"}], ",",
    "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x1", ",", "1970", ",", "\"\<year\>\""}], "}"}], ",", "1970", 
     ",", "2005", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Questions", "Section"],

Cell["\<\
Move the slider so that the year is 1990. What do you notice about the line \
and the slope?\
\>", "Question"],

Cell["", "Answer"],

Cell["\<\
Where on the graph do you see the rate of change of \
Romania\[CloseCurlyQuote]s population changing the most (whether positively \
or negatively)?\
\>", "Question"],

Cell["", "Answer"],

Cell["\<\
What was happening in Romania around the time the population peaked? Why do \
you think the population began to decrease after 1990?\
\>", "Question"],

Cell["", "Answer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Initialization", "Section",
 InitializationGroup->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1970", ",", "2.0252541`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1971", ",", "2.0473448`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1972", ",", "2.067498`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1973", ",", "2.0863943`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1974", ",", "2.1051489`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1975", ",", "2.1245107`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1976", ",", "2.14472`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1977", ",", "2.1652976`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1978", ",", "2.1854285`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1979", ",", "2.2039699`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1980", ",", "2.2201389`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1981", ",", "2.2333737`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1982", ",", "2.2439781`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1983", ",", "2.2530614`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1984", ",", "2.2622238`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1985", ",", "2.2724836`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1986", ",", "2.2844853`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1987", ",", "2.2975102`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1988", ",", "2.3095775`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1989", ",", "2.3179263`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1990", ",", "2.3206717`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1991", ",", "2.3170856`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1992", ",", "2.3080555`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1993", ",", "2.2953033`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1994", ",", "2.2813548`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1995", ",", "2.2680954`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1996", ",", "2.2560871`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1997", ",", "2.2449477`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1998", ",", "2.2344876`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1999", ",", "2.2242156`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2000", ",", "2.2137869`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2001", ",", "2.2032891`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2002", ",", "2.1929915`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2003", ",", "2.1829139`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2004", ",", "2.1730699`*^7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2005", ",", "2.1634674`*^7"}], "}"}]}], "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"model", "=", 
    RowBox[{"LinearModelFit", "[", 
     RowBox[{"data", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "x", ",", 
        SuperscriptBox["x", "2"]}], "}"}], ",", "x"}], "]"}]}], ";"}], " ", 
  "*)"}]], "Input"]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"SlideShow",
InitializationCellEvaluation->Automatic,
WindowSize->{1254, 891},
WindowMargins->{{155, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 23, \
2011)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell[
       TextData[{"Style Definitions for \n", 
         StyleBox["Wolfram Seminars", FontSlant -> "Italic"]}], "Subtitle"], 
      Cell[
       StyleData[StyleDefinitions -> "Default.nb"]], 
      Cell[
       StyleData[StyleDefinitions -> "StyleMenuClear.nb"]], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Definitions", "Section"], 
         Cell[
          StyleData[
          All, "SlideShow", StyleDefinitions -> 
           StyleData[All, "Presentation"]], PageWidth -> WindowWidth, 
          DockedCells -> Cell[
            BoxData[
             GridBox[{{
                TooltipBox[
                 ButtonBox[
                  StyleBox[
                   RowBox[{"  ", "\[EmptySquare]", " "}], FontSize -> 20, 
                   GrayLevel[0.7]], Appearance -> None, 
                  ButtonFunction :> (
                   FEPrivate`NotebookToggleFullScreen[]; {}), Evaluator -> 
                  None], 
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "SlideshowToolbarText", "TooltipToggleFullScreen"]]], 
                StyleBox[
                 RowBox[{
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[FirstPage]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageFirst", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipFirstSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[LeftPointer]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPagePrevious", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipPreviousSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[RightPointer]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageNext", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipNextSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[LastPage]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageLast", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipLastSlide"]]]}], 
                 ButtonBoxOptions -> {Alignment -> {Automatic, 
                    FEPrivate`If[
                    FEPrivate`SameQ[
                    FEPrivate`$OperatingSystem, "Unix"], -0.4, -0.5]}, 
                   Appearance -> "Palette", 
                   ButtonFunction :> (FEPrivate`FrontEndExecute[
                    FrontEnd`FrontEndToken[
                    FrontEnd`ButtonNotebook[], #]]& ), Evaluator -> None, 
                   FrameMargins -> 0, ImageMargins -> 0, ImageSize -> 
                   Medium}], 
                
                DynamicModuleBox[{$CellContext`cells$$ = {}, \
$CellContext`tagFind$$ = False}, 
                 TagBox[
                  DynamicBox[
                   PopupMenuBox[
                    Dynamic[
                    0, With[{$CellContext`nb$ = ButtonNotebook[]}, 
                    SelectionMove[$CellContext`nb$, Before, Notebook, 
                    AutoScroll -> False]; If[$CellContext`tagFind$$, 
                    Do[
                    
                    NotebookFind[$CellContext`nb$, "SlideShowHeader", Next, 
                    CellTags, AutoScroll -> False], {#}], 
                    Do[
                    
                    NotebookFind[$CellContext`nb$, "SlideShowNavigationBar", 
                    Next, CellStyle, AutoScroll -> False], {#}]]; 
                    SelectionMove[$CellContext`nb$, After, Cell, AutoScroll -> 
                    False]; NotebookWrite[$CellContext`nb$, 
                    Cell["", Deletable -> True, ShowCellBracket -> False], 
                    All]; NotebookDelete[$CellContext`nb$]; 
                    SelectionMove[$CellContext`nb$, 
                    If[$CellContext`tagFind$$, Previous, Next], 
                    Cell]]& ], $CellContext`cells$$, 
                    StyleBox[
                    RowBox[{
                    DynamicBox[
                    CurrentValue[{"CounterValue", "SlideShowNavigationBar"}]], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "SlideshowToolbarCounterText"]], 
                    DynamicBox[
                    
                    CurrentValue[{
                    "MaxCounterValue", "SlideShowNavigationBar"}]]}], 
                    "ControlStyle"], Appearance -> None, ImageSize -> 
                    Automatic], ImageSizeCache -> {50., {6., 18.}}], 
                  
                  EventHandlerTag[{
                   "MouseDown" :> 
                    Module[{$CellContext`cnt$, $CellContext`nb$ = 
                    InputNotebook[]}, $CellContext`cells$$ = {}; \
$CellContext`cnt$ = Apply[(
                    NotebookFind[$CellContext`nb$, #, All, #2, AutoScroll -> 
                    False]; CurrentValue[$CellContext`nb$, {
                    "CellCount", True}])& , {{
                    "SlideShowNavigationBar", CellStyle}, {
                    "SlideShowHeader", CellTags}}, {1}]; $CellContext`cnt$ = 
                    Apply[If[$CellContext`tagFind$$ = # == 
                    0, #2, #]& , $CellContext`cnt$]; 
                    SelectionMove[$CellContext`nb$, Before, Notebook, 
                    AutoScroll -> False]; 
                    If[$CellContext`tagFind$$, $CellContext`cells$$ = 
                    Map[# -> StringJoin["Slide ", 
                    ToString[#]]& , 
                    Range[$CellContext`cnt$]], 
                    Do[NotebookFind[$CellContext`nb$, 
                    "SlideShowNavigationBar", Next, CellStyle, AutoScroll -> 
                    False]; SelectionMove[$CellContext`nb$, Next, Cell, 
                    AutoScroll -> False]; AppendTo[$CellContext`cells$$, 
                    ReplaceAll[
                    NotebookRead[$CellContext`nb$], Pattern[$CellContext`s, 
                    Blank[StyleBox]] :> With[{$CellContext`ss = Join[
                    Take[$CellContext`s, 1], 
                    DeleteCases[
                    Rest[$CellContext`s], 
                    Alternatives[
                    Blank[String], 
                    Blank[][FontColor, 
                    Blank[]]]]]}, 
                    
                    Condition[$CellContext`ss, 
                    True]]]], {$CellContext`cnt$}]; $CellContext`cells$$ = 
                    Replace[
                    Part[$CellContext`cells$$, All, 1], {BoxData[
                    Pattern[$CellContext`c, 
                    Blank[]]] :> $CellContext`c, TextData[
                    Pattern[$CellContext`c, 
                    Blank[]]] :> RowBox[
                    If[
                    
                    ListQ[$CellContext`c], $CellContext`c, \
{$CellContext`c}]]}, 1]; $CellContext`cells$$ = 
                    Thread[Range[$CellContext`cnt$] -> \
$CellContext`cells$$]]], PassEventsDown -> True, EvaluationOrder -> Before, 
                    PassEventsDown -> Automatic, PassEventsUp -> True}]], 
                 DynamicModuleValues :> {}]}}, AutoDelete -> False, 
              GridBoxItemSize -> {"Columns" -> {Automatic, Fit, Automatic}}]],
             "DockedCell", CellDynamicExpression :> If[CurrentValue[
                EvaluationNotebook[], {TaggingRules, "DisableController"}] === 
              True, Null, 
              (FrontEndExecute[
               FrontEnd`FrontEndToken[
                FrontEnd`InputNotebook[], #]]& )[
               Switch[
                ControllerState["Apple IR", {"B1", "B2"}], {True, 
                 Blank[]}, "ScrollPagePrevious", {
                 Blank[], True}, "ScrollPageNext", 
                Blank[], None]]], Magnification -> 0.75], 
          ScrollingOptions -> {
           "PagewiseDisplay" -> True, "VerticalScrollRange" -> Fit}, 
          ShowGroupOpener -> False, MenuSortingValue -> 1300], 
         Cell[
          StyleData["DockedCell"], Editable -> False, Evaluator -> "Local", 
          PageWidth -> WindowWidth, CellFrame -> {{0, 0}, {0, 0}}, 
          ShowSelection -> True, CellMargins -> {{0, 0}, {0, 0}}, 
          CellElementSpacings -> {
           "ClosedCellHeight" -> 0, "ClosedGroupTopMargin" -> 0}, 
          DynamicUpdating -> True, CellFrameMargins -> {{0, 0}, {0, 4}}, 
          ContextMenu -> None, ComponentwiseContextMenu -> {}, 
          ShowStringCharacters -> False, LineBreakWithin -> False, 
          Magnification -> 1, Background -> GrayLevel[0.97], 
          TooltipBoxOptions -> {TooltipDelay -> Automatic}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], MenuSortingValue -> 1, MenuCommandKey -> "1",
              FontFamily -> "Georgia", FontSize -> 36, FontWeight -> Plain, 
             FontColor -> RGBColor[0.796078, 0.0705882, 0]], 
            Cell[
             StyleData["Title", "Presentation"], 
             CellMargins -> {{90, 100}, {10, 100}}, FontSize -> 54], 
            Cell[
             StyleData["Title", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], MenuSortingValue -> 100, MenuCommandKey -> 
             "2", FontFamily -> "Georgia", FontSize -> 24, FontWeight -> 
             "Plain", FontSlant -> "Italic"], 
            Cell[
             StyleData["Subtitle", "Presentation"], 
             CellMargins -> {{90, 100}, {100, 20}}, FontSize -> 32], 
            Cell[
             StyleData["Subtitle", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], MenuSortingValue -> 200, 
             MenuCommandKey -> "3", FontFamily -> "Georgia", FontSize -> 20, 
             FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[0.2]], 
            Cell[
             StyleData["Subsubtitle", "Presentation"], 
             CellMargins -> {{90, 20}, {2, 120}}, LineSpacing -> {1.25, 1}, 
             FontSize -> 26], 
            Cell[
             StyleData["Subsubtitle", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DateSection"], CellMargins -> {{30, 0}, {12, 24}}, 
             ShowStringCharacters -> False], 
            Cell[
             StyleData["DateSection", "Presentation"], 
             CellMargins -> {{90, 20}, {2, 36}}, ShowStringCharacters -> 
             False, FontSize -> 21], 
            Cell[
             StyleData["DateSection", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Sections", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Chapter"], CellMargins -> {{27, Inherited}, {8, 34}}, 
             CounterIncrements -> {"Chapter"}, MenuSortingValue -> 2410, 
             FontFamily -> "Georgia", FontSize -> 28, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098], CellTags -> "Chapter"], 
            Cell[
             StyleData["Chapter", "Presentation"], CellFrame -> None, 
             CellMargins -> {{80, 60}, {20, 30}}, FontSize -> 36], 
            Cell[
             StyleData["Chapter", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "LargeChapter", StyleDefinitions -> StyleData["Chapter"]], 
             CellMargins -> {{27, Inherited}, {8, 34}}, MenuSortingValue -> 
             2430, FontFamily -> "Georgia", FontSize -> 30, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["LargeChapter", "Presentation"], 
             CellMargins -> {{100, 100}, {10, 150}}, FontSize -> 54], 
            Cell[
             StyleData["LargeChapter", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> 0, MenuSortingValue -> 1200, 
             MenuCommandKey -> "4", FontFamily -> "Georgia", FontSize -> 24, 
             FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["Section", "Presentation"], CellFrame -> None, 
             CellMargins -> {{80, 14}, {30, 30}}, FontFamily -> "Georgia", 
             FontSize -> 34, FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["Section", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> "\[RightGuillemet]", 
             CellGroupingRules -> {"SectionGrouping", 40}, MenuSortingValue -> 
             1300, MenuCommandKey -> "5", FontFamily -> "Georgia", FontSize -> 
             22, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
            Cell[
             StyleData["Subsection", "Presentation"], 
             CellMargins -> {{84, 60}, {12, 20}}, FontSize -> 25], 
            Cell[
             StyleData["Subsection", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> "\[RightGuillemet]", 
             MenuSortingValue -> 1400, MenuCommandKey -> "6", FontFamily -> 
             "Georgia", FontSize -> 20, FontWeight -> "Plain", FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["Subsubsection", "Presentation"], 
             CellMargins -> {{88, 60}, {0, 12}}, FontSize -> 22], 
            Cell[
             StyleData["Subsubsection", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "MoreExamplesSection", StyleDefinitions -> 
              StyleData["Subsubsection"]], CellDingbat -> None, 
             ShowGroupOpener -> True, 
             CellGroupingRules -> {"SectionGrouping", 45}, MenuSortingValue -> 
             2100, FontWeight -> "Plain", FontColor -> 
             RGBColor[0.636862, 0.0564706, 0.]], 
            Cell[
             StyleData["MoreExamplesSection", "Presentation"], 
             CellMargins -> {{88, 60}, {20, 12}}], 
            Cell[
             StyleData["MoreExamplesSection", "SlideShow"], 
             WholeCellGroupOpener -> True, 
             CellMargins -> {{88, 60}, {20, 12}}, FontWeight -> "Plain"]}, 
           Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], MenuSortingValue -> 2000, MenuCommandKey -> 
             "7", FontFamily -> "Georgia", FontSize -> 18], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{80, 20}, {12, 12}}, LineSpacing -> {1.25, 1}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["Text", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MathCaption"], MenuSortingValue -> 2010, 
             MenuCommandKey -> "8", FontFamily -> "Georgia", FontSize -> 18, 
             FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["MathCaption", "Presentation"], 
             CellMargins -> {{120, 12}, {6, 34}}, LineSpacing -> {1.25, 1}, 
             FontSize -> 20], 
            Cell[
             StyleData["MathCaption", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "IntegrationMathCaption", StyleDefinitions -> 
              StyleData["MathCaption"]], CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Integration", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[0.811765, 0.117647, 0.145098], 
                  BoxFrame -> 0, FrameStyle -> None, 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}], 
            Cell[
             StyleData["IntegrationMathCaption", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, 
             CellFrameMargins -> {{10, 0}, {0, 5}}, FontSize -> 20], 
            Cell[
             StyleData["IntegrationMathCaption", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}, 
             CellFrameMargins -> {{10, 0}, {0, 5}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "AutomationMathCaption", StyleDefinitions -> 
              StyleData["IntegrationMathCaption"]], 
             CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Automation", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[0.811765, 0.117647, 0.145098], 
                  BoxFrame -> 0, FrameStyle -> None, 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}], 
            Cell[
             StyleData["AutomationMathCaption", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 20], 
            Cell[
             StyleData["AutomationMathCaption", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Comment", StyleDefinitions -> StyleData["Text"]], 
             CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Comment", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[1., 0.647059, 0], BoxFrame -> 1, 
                  FrameStyle -> RGBColor[1., 0.647059, 0], 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}, 
             MenuSortingValue -> 2200, FontSize -> 14], 
            Cell[
             StyleData["Comment", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 16], 
            Cell[
             StyleData["Comment", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 16]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], 
             CellMargins -> {{60, Inherited}, {Inherited, Inherited}}, 
             StripStyleOnPaste -> True, DefaultFormatType -> 
             DefaultInputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> True, 
             MenuSortingValue -> 1700, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], 
             CellMargins -> {{120, Inherited}, {
               Inherited 1.75, Inherited 1.75}}, LineSpacing -> {1, 5}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["DisplayFormula", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Items", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Item"], CellDingbat -> "\[RightGuillemet] ", 
             LineSpacing -> {1.5, 0}, MenuSortingValue -> 2700, FontFamily -> 
             "Georgia", FontSize -> 18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["Item", "Presentation"], 
             CellMargins -> {{116, 20}, {12, 12}}, FontFamily -> "Georgia", 
             FontSize -> 20], 
            Cell[
             StyleData["Item", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemParagraph"], MenuSortingValue -> 2710, FontFamily -> 
             "Georgia", FontSize -> 18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["ItemParagraph", "Presentation"], 
             CellMargins -> {{120, 90}, {12, 12}}, LineSpacing -> {1.25, 0}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["ItemParagraph", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemNumbered"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2720, FontFamily -> "Georgia", FontSize -> 
             18, FontColor -> GrayLevel[0.25]], 
            Cell[
             StyleData["ItemNumbered", "Presentation"], 
             CellMargins -> {{116, 20}, {12, 12}}, FontFamily -> "Georgia", 
             FontSize -> 20], 
            Cell[
             StyleData["ItemNumbered", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subitem"], CellDingbat -> "\[RightGuillemet] ", 
             LineSpacing -> {1.5, 0}, MenuSortingValue -> 2730, FontFamily -> 
             "Georgia", FontSize -> 16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["Subitem", "Presentation"], 
             CellMargins -> {{136, 20}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 21], 
            Cell[
             StyleData["Subitem", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubitemParagraph"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2740, FontFamily -> "Georgia", FontSize -> 
             16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["SubitemParagraph", "Presentation"], 
             CellMargins -> {{136, 90}, {10, 8}}, FontFamily -> "Georgia", 
             FontSize -> 18], 
            Cell[
             StyleData["SubitemParagraph", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubitemNumbered"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2750, FontFamily -> "Georgia", FontSize -> 
             16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["SubitemNumbered", "Presentation"], 
             CellMargins -> {{136, 20}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 18], 
            Cell[
             StyleData["SubitemNumbered", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input and Output", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], MenuSortingValue -> 2020, MenuCommandKey -> 
             "9", FontSize -> 18], 
            Cell[
             StyleData["Input", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Input", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], 
             CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
             LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9, FontColor -> 
             RGBColor[0.269993, 0.308507, 0.6]], 
            Cell[
             StyleData["CellLabel", "Presentation"], 
             CellMargins -> {{12, Inherited}, {Inherited 1.5, Inherited 1.5}},
              FontSize -> 12], 
            Cell[
             StyleData["CellLabel", "SlideShow"], 
             CellMargins -> {{12, Inherited}, {Inherited 1.5, Inherited 1.5}},
              FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaShort"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShort", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShort", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaShortInput"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShortInput", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShortInput", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaLong"], FontFamily -> "Helvetica", 
             FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLong", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLong", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaLongInput"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLongInput", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLongInput", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], MenuSortingValue -> 2030, FontSize -> 18], 
            Cell[
             StyleData["Output", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Output", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], FontSize -> 18], 
            Cell[
             StyleData["Print", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Print", "SlideShow"]]}, Closed]], 
         Cell[
          StyleData["MSG"], FontSize -> 16]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles of Links", "Section"], 
         Cell[
          StyleData["Link", "SlideShow"]], 
         Cell[
          StyleData["SearchLink", StyleDefinitions -> StyleData["Link"]]], 
         Cell[
          StyleData["FunctionLink"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Special Styles", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Picture"], CellMargins -> {{100, 100}, {20, 20}}, 
             ShowStringCharacters -> False, MenuSortingValue -> 5000, 
             Magnification -> 1], 
            Cell[
             StyleData["Picture", "Presentation"], 
             CellMargins -> {{100, 100}, {20, 20}}, Magnification -> 1], 
            Cell[
             StyleData["Picture", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "PictureCaption", StyleDefinitions -> StyleData["Text"]], 
             CellDingbat -> "\[FilledUpTriangle]", 
             CellMargins -> {{114, 100}, {15, 4}}, ShowStringCharacters -> 
             False, MenuSortingValue -> 5100, FontSize -> 14, FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["PictureCaption", "Presentation"], 
             CellMargins -> {{114, 100}, {20, 0}}, FontSize -> 16], 
            Cell[
             StyleData["PictureCaption", "SlideShow"], 
             CellMargins -> {{114, 100}, {20, 0}}, FontFamily -> "Helvetica", 
             FontSize -> 17]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OverviewTitle"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["OverviewTitle", "Presentation"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["OverviewTitle", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OverviewSection"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["OverviewSection", "Presentation"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["OverviewSection", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChapterTagline"], CellMargins -> {{60, 90}, {15, 0}}, 
             MenuSortingValue -> 2420, FontFamily -> "Georgia", FontSize -> 
             20, FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["ChapterTagline", "Presentation"], 
             CellMargins -> {{90, 90}, {15, 0}}, FontSize -> 24], 
            Cell[
             StyleData["ChapterTagline", "SlideShow"]]}, Closed]], 
         Cell[
          StyleData["PlotLabel"], FontFamily -> "Helvetica", FontSize -> 14], 
         Cell[
          StyleData["NonPrintButton"], 
          CellMargins -> {{128, Inherited}, {16, 0}}, FontFamily -> 
          "Helvetica", FontSize -> 12, FontColor -> GrayLevel[1], 
          ButtonBoxOptions -> {
           Background -> RGBColor[0.811765, 0.117647, 0.145098], 
            ButtonMargins -> 4}], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"]], 
            Cell[
             StyleData["Program", "SlideShow"], 
             CellMargins -> {{116, 48}, {16, 16}}, FontSize -> 18]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Editorial"], ShowCellBracket -> Automatic, 
             CellMargins -> {{24, 10}, {6, 6}}, 
             CellBracketOptions -> {
              "Color" -> RGBColor[0.786999, 0.0386053, 0.0571756]}, 
             CellFrameLabels -> {{
                Cell[
                 TextData[{"Edit:"}], FontFamily -> "Helvetica", FontSize -> 
                 16, FontWeight -> "Bold", CellBaseline -> Baseline], None}, {
               None, None}}, DefaultNewInlineCellStyle -> "None", Hyphenation -> 
             True, LineSpacing -> {1, 3}, LanguageCategory -> 
             "NaturalLanguage", FontFamily -> "Helvetica", FontSize -> 19, 
             FontColor -> RGBColor[1, 0, 0]], 
            Cell[
             StyleData["Editorial", "SlideShow"], 
             CellMargins -> {{Inherited, Inherited}, {0, 0}}, 
             CellElementSpacings -> {
              "CellMinHeight" -> 1, "ClosedCellHeight" -> 0}, CellOpen -> 
             False]}, Closed]], 
         Cell[
          StyleData["DialogStyle"], FontSize -> 17], 
         Cell[
          StyleData["TooltipLabel"], CellFrame -> 1., CellFrameMargins :> 
          CurrentValue["TooltipFrameMargins"], CellFrameColor :> 
          CurrentValue[{"SystemColor", "TooltipFrame"}], TextAlignment -> 
          Left, TextJustification -> 0., ShowStringCharacters -> False, 
          FontFamily :> CurrentValue["TooltipFontFamily"], FontSize :> 
          CurrentValue["TooltipFontSize"], FontWeight -> "Plain", FontSlant -> 
          "Plain", Magnification -> 1.5, FontColor :> 
          CurrentValue[{"SystemColor", "TooltipText"}], FontOpacity -> 1., 
          Background :> CurrentValue[{"SystemColor", "Tooltip"}]], 
         Cell[
          StyleData["Question"], CellFrame -> {{0.25, 0.25}, {0.25, 0.25}}, 
          CellMargins -> {{145, 24}, {0, 10}}, CellFrameColor -> 
          GrayLevel[0.65], FontFamily -> "Georgia", FontSize -> 18, 
          Background -> RGBColor[0.95, 0.95, 0.95]], 
         Cell[
          StyleData["Answer"], CellFrame -> {{0.25, 0.25}, {0.25, 0}}, 
          CellMargins -> {{72, 24}, {10, 0}}, CellFrameColor -> 
          GrayLevel[0.65], CellFrameLabels -> {{
             Cell[
              TextData["Answer:"], "LabelStyleShort"], None}, {None, None}}, 
          FontFamily -> "Georgia", FontSize -> 18, Background -> 
          RGBColor[0.9999, 0.9999, 0.9999]], 
         Cell[
          StyleData["ClassInfo"], CellMargins -> {{88, 3}, {4, 18}}, 
          MenuSortingValue -> 10000, FontFamily -> "Arial", FontSize -> 24, 
          FontWeight -> "Plain", FontSlant -> "Plain", 
          FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
         Cell[
          StyleData["TheoremBox"], CellFrame -> 1, 
          CellMargins -> {{227, 152}, {4, 4}}, CellFrameColor -> GrayLevel[0],
           MenuSortingValue -> 10000, FontFamily -> "Arial", FontSize -> 16, 
          FontWeight -> "Plain", FontSlant -> "Plain", 
          FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}, 
          Background -> RGBColor[0.94, 0.91, 0.88]]}, Open]]}, Open]]}, 
  Visible -> False, FrontEndVersion -> 
  "8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 23, 2011)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 34, 0, 1, "SlideShowNavigationBar"],
Cell[616, 24, 46, 0, 172, "Title"],
Cell[665, 26, 18, 0, 20, "Spacer"],
Cell[686, 28, 155, 7, 77, "ClassInfo"],
Cell[844, 37, 28, 4, 46, "Spacer"],
Cell[875, 43, 201, 5, 75, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1113, 53, 34, 0, 1, "SlideShowNavigationBar"],
Cell[CellGroupData[{
Cell[1172, 57, 58, 2, 98, "Section"],
Cell[1233, 61, 230, 7, 46, "Text"],
Cell[1466, 70, 130, 3, 65, "MathCaption"],
Cell[1599, 75, 414, 13, 37, "Input"],
Cell[2016, 90, 18, 0, 20, "Spacer"],
Cell[CellGroupData[{
Cell[2059, 94, 47, 0, 60, "Subsection"],
Cell[2109, 96, 155, 6, 46, "Text"],
Cell[2267, 104, 64, 1, 37, "Input"],
Cell[2334, 107, 92, 2, 46, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2487, 116, 34, 0, 1, "SlideShowNavigationBar"],
Cell[CellGroupData[{
Cell[2546, 120, 31, 0, 98, "Section"],
Cell[2580, 122, 118, 3, 47, "Text"],
Cell[2701, 127, 220, 6, 47, "Input"],
Cell[2924, 135, 17, 0, 20, "Space"],
Cell[CellGroupData[{
Cell[2966, 139, 50, 0, 60, "Subsection"],
Cell[3019, 141, 195, 5, 47, "Text"],
Cell[3217, 148, 283, 9, 37, "Input"],
Cell[3503, 159, 137, 5, 46, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3701, 171, 34, 0, 1, "SlideShowNavigationBar"],
Cell[CellGroupData[{
Cell[3760, 175, 35, 0, 98, "Section"],
Cell[3798, 177, 301, 5, 76, "Text"],
Cell[CellGroupData[{
Cell[4124, 186, 1880, 47, 245, "Input"],
Cell[6007, 235, 1254, 31, 301, "Output"]
}, {2}]],
Cell[7273, 269, 229, 5, 95, "MathCaption"],
Cell[7505, 276, 79, 2, 37, "Input"],
Cell[7587, 280, 79, 2, 37, "Input"],
Cell[7669, 284, 79, 2, 37, "Input"],
Cell[7751, 288, 164, 3, 75, "Text"],
Cell[7918, 293, 173, 5, 66, "MathCaption"],
Cell[8094, 300, 120, 3, 37, "Input"],
Cell[8217, 305, 221, 5, 94, "MathCaption"],
Cell[8441, 312, 1816, 50, 196, "Input"],
Cell[10260, 364, 18, 0, 20, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10327, 370, 34, 0, 1, "SlideShowNavigationBar"],
Cell[CellGroupData[{
Cell[10386, 374, 28, 0, 98, "Section"],
Cell[10417, 376, 120, 3, 47, "Question"],
Cell[10540, 381, 18, 0, 47, "Answer"],
Cell[10561, 383, 175, 4, 47, "Question"],
Cell[10739, 389, 18, 0, 47, "Answer"],
Cell[10760, 391, 160, 3, 69, "Question"],
Cell[10923, 396, 18, 0, 47, "Answer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10990, 402, 34, 0, 1, "SlideShowNavigationBar"],
Cell[CellGroupData[{
Cell[11049, 406, 61, 1, 98, "Section",
 InitializationGroup->True],
Cell[11113, 409, 2907, 77, 222, "Input"],
Cell[14023, 488, 287, 9, 46, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
